==> d3Network_0.3.1.tar.gz: d3Network/man/d3Tree.Rd <==
\name{d3Tree}
\alias{d3Tree}
\title{Creates a D3 JavaScript Reingold-Tilford Tree network graph.}
\source{
  Reingold. E. M., and Tilford, J. S. (1981). Tidier
  Drawings of Trees. IEEE Transactions on Software
  Engineering, SE-7(2), 223-228.

  Mike Bostock \url{http://bl.ocks.org/mbostock/4063550}.
}
\usage{
  d3Tree(List, height = 600, width = 900, fontsize = 10,
    linkColour = "#ccc", nodeColour = "#3182bd",
    textColour = "#3182bd", opacity = 0.9, diameter = 980,
    zoom = FALSE, standAlone = TRUE, file = NULL,
    iframe = FALSE,
    d3Script = "http://d3js.org/d3.v3.min.js")
}
\arguments{
  \item{List}{a hierarchical list object with a root node
  and children.}

  \item{height}{numeric height for the network graph's
  frame area in pixels.}

  \item{width}{numeric width for the network graph's frame
  area in pixels.}

  \item{fontsize}{numeric font size in pixels for the node
  text labels.}

  \item{linkColour}{character string specifying the colour
  you want the link lines to be. Multiple formats supported
  (e.g. hexadecimal).}

  \item{nodeColour}{character string specifying the colour
  you want the node circles to be. Multiple formats
  supported (e.g. hexadecimal).}

  \item{textColour}{character string specifying the colour
  you want the text to be before they are clicked. Multiple
  formats supported (e.g. hexadecimal).}

  \item{opacity}{numeric value of the proportion opaque you
  would like the graph elements to be.}

  \item{diameter}{numeric diameter for the network in
  pixels.}

  \item{zoom}{logical, whether or not to enable the ability
  to use the mouse scroll-wheel to zoom in and out of the
  graph.}

  \item{standAlone}{logical, whether or not to return a
  complete HTML document (with head and foot) or just the
  script.}

  \item{file}{a character string of the file name to save
  the resulting graph. If a file name is given a standalone
  webpage is created, i.e. with a header and footer. If
  \code{file = NULL} then result is returned to the
  console.}

  \item{iframe}{logical. If \code{iframe = TRUE} then the
  graph is saved to an external file in the working
  directory and an HTML \code{iframe} linking to the file
  is printed to the console. This is useful if you are
  using Slidify and many other HTML slideshow framworks and
  want to include the graph in the resulting page. If you
  set the knitr code chunk \code{results='asis'} then the
  graph will be rendered in the output. Usually, you can
  use \code{iframe = FALSE} if you are creating simple
  knitr Markdown or HTML pages. Note: you do not need to
  specify the file name if \code{iframe = TRUE}, however if
  you do, do not include the file path.}

  \item{d3Script}{a character string that allows you to
  specify the location of the d3.js script you would like
  to use. The default is
  \url{http://d3js.org/d3.v3.min.js}.}
}
\description{
  Creates a D3 JavaScript Reingold-Tilford Tree network
  graph.
}
\examples{
## Create tree from R list
# Create hierarchical list
CanadaPC <- list(name = "Canada", children = list(list(name = "Newfoundland",
                    children = list(list(name = "St. John's"))),
               list(name = "PEI",
                    children = list(list(name = "Charlottetown"))),
               list(name = "Nova Scotia",
                    children = list(list(name = "Halifax"))),
               list(name = "New Brunswick",
                    children = list(list(name = "Fredericton"))),
               list(name = "Quebec",
                    children = list(list(name = "Montreal"),
                                    list(name = "Quebec City"))),
               list(name = "Ontario",
                    children = list(list(name = "Toronto"),
                                    list(name = "Ottawa"))),
               list(name = "Manitoba",
                    children = list(list(name = "Winnipeg"))),
               list(name = "Saskatchewan",
                    children = list(list(name = "Regina"))),
               list(name = "Nunavuet",
                    children = list(list(name = "Iqaluit"))),
               list(name = "NWT",
                    children = list(list(name = "Yellowknife"))),
               list(name = "Alberta",
                    children = list(list(name = "Edmonton"))),
               list(name = "British Columbia",
                    children = list(list(name = "Victoria"),
                                    list(name = "Vancouver"))),
               list(name = "Yukon",
                    children = list(list(name = "Whitehorse")))
))

# Create tree
d3Tree(List = CanadaPC, fontsize = 10, diameter = 500)

## Create tree from JSON formatted data
# Download JSON data
library(RCurl)
URL <- "https://raw.github.com/christophergandrud/d3Network/master/JSONdata/flare.json"
Flare <- getURL(URL)

# Convert to list format
Flare <- rjson::fromJSON(Flare)

# Recreate Bostock example from http://bl.ocks.org/mbostock/4063550
d3Tree(List = Flare, file = "Flare.html",
       fontsize = 10, opacity = 0.9, diameter = 1000)
}

==> d3Network_0.4.2.tar.gz: d3Network/man/d3Tree.Rd <==
\name{d3Tree}
\alias{d3Tree}
\title{Creates a D3 JavaScript Reingold-Tilford Tree network graph.}
\source{
  Reingold. E. M., and Tilford, J. S. (1981). Tidier
  Drawings of Trees. IEEE Transactions on Software
  Engineering, SE-7(2), 223-228.

  Mike Bostock \url{http://bl.ocks.org/mbostock/4063550}.
}
\usage{
  d3Tree(List, height = 600, width = 900, fontsize = 10,
    linkColour = "#ccc", nodeColour = "#3182bd",
    textColour = "#3182bd", opacity = 0.9, diameter = 980,
    zoom = FALSE, standAlone = TRUE, file = NULL,
    iframe = FALSE,
    d3Script = "http://d3js.org/d3.v3.min.js")
}
\arguments{
  \item{List}{a hierarchical list object with a root node
  and children.}

  \item{height}{numeric height for the network graph's
  frame area in pixels.}

  \item{width}{numeric width for the network graph's frame
  area in pixels.}

  \item{fontsize}{numeric font size in pixels for the node
  text labels.}

  \item{linkColour}{character string specifying the colour
  you want the link lines to be. Multiple formats supported
  (e.g. hexadecimal).}

  \item{nodeColour}{character string specifying the colour
  you want the node circles to be. Multiple formats
  supported (e.g. hexadecimal).}

  \item{textColour}{character string specifying the colour
  you want the text to be before they are clicked. Multiple
  formats supported (e.g. hexadecimal).}

  \item{opacity}{numeric value of the proportion opaque you
  would like the graph elements to be.}

  \item{diameter}{numeric diameter for the network in
  pixels.}

  \item{zoom}{logical, whether or not to enable the ability
  to use the mouse scroll-wheel to zoom in and out of the
  graph.}

  \item{standAlone}{logical, whether or not to return a
  complete HTML document (with head and foot) or just the
  script.}

  \item{file}{a character string of the file name to save
  the resulting graph. If a file name is given a standalone
  webpage is created, i.e. with a header and footer. If
  \code{file = NULL} then result is returned to the
  console.}

  \item{iframe}{logical. If \code{iframe = TRUE} then the
  graph is saved to an external file in the working
  directory and an HTML \code{iframe} linking to the file
  is printed to the console. This is useful if you are
  using Slidify and many other HTML slideshow framworks and
  want to include the graph in the resulting page. If you
  set the knitr code chunk \code{results='asis'} then the
  graph will be rendered in the output. Usually, you can
  use \code{iframe = FALSE} if you are creating simple
  knitr Markdown or HTML pages. Note: you do not need to
  specify the file name if \code{iframe = TRUE}, however if
  you do, do not include the file path.}

  \item{d3Script}{a character string that allows you to
  specify the location of the d3.js script you would like
  to use. The default is
  \url{http://d3js.org/d3.v3.min.js}.}
}
\description{
  Creates a D3 JavaScript Reingold-Tilford Tree network
  graph.
}
\examples{
## Create tree from R list
# Create hierarchical list
CanadaPC <- list(name = "Canada", children = list(list(name = "Newfoundland",
                    children = list(list(name = "St. John's"))),
               list(name = "PEI",
                    children = list(list(name = "Charlottetown"))),
               list(name = "Nova Scotia",
                    children = list(list(name = "Halifax"))),
               list(name = "New Brunswick",
                    children = list(list(name = "Fredericton"))),
               list(name = "Quebec",
                    children = list(list(name = "Montreal"),
                                    list(name = "Quebec City"))),
               list(name = "Ontario",
                    children = list(list(name = "Toronto"),
                                    list(name = "Ottawa"))),
               list(name = "Manitoba",
                    children = list(list(name = "Winnipeg"))),
               list(name = "Saskatchewan",
                    children = list(list(name = "Regina"))),
               list(name = "Nunavuet",
                    children = list(list(name = "Iqaluit"))),
               list(name = "NWT",
                    children = list(list(name = "Yellowknife"))),
               list(name = "Alberta",
                    children = list(list(name = "Edmonton"))),
               list(name = "British Columbia",
                    children = list(list(name = "Victoria"),
                                    list(name = "Vancouver"))),
               list(name = "Yukon",
                    children = list(list(name = "Whitehorse")))
))

# Create tree
d3Tree(List = CanadaPC, fontsize = 10, diameter = 500)

## Create tree from JSON formatted data
## dontrun
## Download JSON data
# library(RCurl)
# URL <- "https://raw.github.com/christophergandrud/d3Network/master/JSONdata/flare.json"
# Flare <- getURL(URL)

## Convert to list format
# Flare <- rjson::fromJSON(Flare)

## Recreate Bostock example from http://bl.ocks.org/mbostock/4063550
# d3Tree(List = Flare, file = "Flare.html",
#        fontsize = 10, opacity = 0.9, diameter = 1000)
}
